@@ -13,6 +13,7 @@
  * daniel@veillard.com
  */
 
+#define IN_LIBXSLT
 #include "libxslt.h"
 
 #include <string.h>
@@ -916,7 +917,11 @@ xsltParseStylesheetPreserveSpace(xsltStylesheetPtr style, xmlNodePtr cur) {
 	    if (xmlStrEqual(element, (const xmlChar *)"*")) {
 		style->stripAll = -1;
 	    } else {
-		xmlHashAddEntry(style->stripSpaces, element,
+		const xmlChar *URI;
+
+                URI = xsltGetQNameURI(cur, &element);
+
+		xmlHashAddEntry2(style->stripSpaces, element, URI,
 				(xmlChar *) "preserve");
 	    }
 	    xmlFree(element);
@@ -1031,7 +1036,11 @@ xsltParseStylesheetStripSpace(xsltStylesheetPtr style, xmlNodePtr cur) {
 	    if (xmlStrEqual(element, (const xmlChar *)"*")) {
 		style->stripAll = 1;
 	    } else {
-		xmlHashAddEntry(style->stripSpaces, element,
+		const xmlChar *URI;
+
+                URI = xsltGetQNameURI(cur, &element);
+
+		xmlHashAddEntry2(style->stripSpaces, element, URI,
 			        (xmlChar *) "strip");
 	    }
 	    xmlFree(element);
@@ -1936,6 +1945,7 @@ xsltParseStylesheetProcess(xsltStylesheetPtr ret, xmlDocPtr doc) {
 	template->content = doc->children;
 	xsltAddTemplate(ret, template, NULL, NULL);
     }
+    xsltResolveStylesheetAttributeSet(ret);
 
     return(ret);
 }
