@@ -275,6 +275,20 @@ libxslt_xsltRegisterAllElement(ATTRIBUTE_UNUSED PyObject *self, PyObject *args)
     return(Py_None);
 }
 
+PyObject *
+libxslt_xsltResolveStylesheetAttributeSet(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
+    xsltStylesheetPtr style;
+    PyObject *pyobj_style;
+
+    if (!PyArg_ParseTuple(args, (char *)"O:xsltResolveStylesheetAttributeSet", &pyobj_style))
+        return(NULL);
+    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+
+    xsltResolveStylesheetAttributeSet(style);
+    Py_INCREF(Py_None);
+    return(Py_None);
+}
+
 PyObject *
 libxslt_xsltInitCtxtExts(ATTRIBUTE_UNUSED PyObject *self, PyObject *args) {
     PyObject *py_retval;
